@@ -2,7 +2,7 @@ package Mouse::Spec;
 use strict;
 use warnings;
 
-our $VERSION = '0.42';
+our $VERSION = '0.43';
 
 our $MouseVersion = $VERSION;
 our $MooseVersion = '0.93';
@@ -19,7 +19,7 @@ Mouse::Spec - To what extent Mouse is compatible with Moose
 
 =head1 VERSION
 
-This document describes Mouse version 0.42
+This document describes Mouse version 0.43
 
 =head1 SYNOPSIS
 
@@ -30,16 +30,21 @@ This document describes Mouse version 0.42
 
 =head1 DESCRIPTION
 
-(TODO)
+Mouse is a subset of Moose. This document describes to what extend Mouse is
+compatible with Moose.
 
 =head2 Compatibility with Moose
 
+The sugary API is highly compatible with Moose.
+
 =head2 Incompatibility with Moose
 
 =head3 Meta object protocols
 
-Any MOP has no attributes, so
-C<< $metaclass->meta->make_immutable() >> does not yet work as you expect.
+Any MOP in Mouse has no attributes.
+
+And C<< $metaclass->meta->make_immutable() >> does not yet work as you expect.
+B<Don not make metaclasses immutalbe>.
 
 =head3 Mouse::Meta::Instance
 
@@ -49,10 +54,10 @@ Meta instance mechanism is not implemented.
 
 Role exclusion, C<exclude()>, is not implemented.
 
-=head3 -traits and -metaclass in Mouse::Exporter
+=head3 -metaclass in Mouse::Exporter
 
-C<< use Mouse -traits => ... >> and C<< use Mouse -metaclass => ... >> are not
-yet implemented.
+C<< use Mouse -metaclass => ... >> are not implemented.
+Use C<< use Mouse -traits => ... >> instead.
 
 =head2 Notes about Moose::Cookbook
 
